import * as UI from '../../legacy/legacy.js';
import type { Column, Row, SortState } from './DataGridUtils.js';
export interface DataGridContextMenusConfiguration {
    headerRow?: (menu: UI.ContextMenu.ContextMenu, columns: readonly Column[]) => void;
    bodyRow?: (menu: UI.ContextMenu.ContextMenu, columns: readonly Column[], row: Readonly<Row>) => void;
}
export interface DataGridData {
    columns: Column[];
    rows: Row[];
    activeSort: SortState | null;
    contextMenus?: DataGridContextMenusConfiguration;
}
export declare class DataGrid extends HTMLElement {
    #private;
    static readonly litTagName: import("../../lit-html/static.js").Static;
    connectedCallback(): void;
    get data(): DataGridData;
    set data(data: DataGridData);
    private shouldAutoScrollToBottom;
    private scrollToBottomIfRequired;
    private engageResizeObserver;
    private userHasCellFocused;
    private getTableElementForCellUserHasFocused;
    private focusTableCellInDOM;
    private focusCellIfRequired;
    private onTableKeyDown;
    private onColumnHeaderClick;
    /**
     * Applies the aria-sort label to a column's th.
     * Guidance on values of attribute taken from
     * https://www.w3.org/TR/wai-aria-practices/examples/grid/dataGrids.html.
     */
    private ariaSortForHeader;
    private renderEmptyFillerRow;
    private cleanUpAfterResizeColumnComplete;
    private onResizePointerDown;
    private onResizePointerMove;
    private onResizePointerUp;
    private renderResizeForCell;
    private getIndexOfLastVisibleColumn;
    /**
     * This function is called when the user right clicks on the header row of the
     * data grid.
     */
    private onHeaderContextMenu;
    private onBodyRowContextMenu;
    private onScroll;
    private alignScrollHandlers;
    /**
     * Calculates the index of the first row we want to render, and the last row we want to render.
     * Pads in each direction by PADDING_ROWS_COUNT so we render some rows that are off scren.
     */
    private calculateTopAndBottomRowIndexes;
    private onFocusOut;
    private tabbableCell;
    /**
     * Renders the data-grid table. Note that we do not render all rows; the
     * performance cost are too high once you have a large enough table. Instead
     * we calculate the size of the container we are rendering into, and then
     * render only the rows required to fill that table (plus a bit extra for
     * padding).
     */
    private render;
}
declare global {
    interface HTMLElementTagNameMap {
        'devtools-data-grid': DataGrid;
    }
}
